@@ -11,7 +11,8 @@ from .log import logger
 # 如果header字段变化，那么格式也会变化
 HEADER_ATTRS = OrderedDict([
     ('magic', ('i', 2037952207)),
-    ('version', ('i', 0)),
+    ('version', ('h', 0)),
+    ('flag', ('h', 0)),
     ('packet_len', ('i', 0)),
     ('cmd', ('i', 0)),
     ('ret', ('i', 0)),
